@@ -1,9 +1,13 @@
-from zope.app.component.hooks import getSite
 from Products.CMFCore.utils import getToolByName
 from zope.interface import directlyProvides
 from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm
 from zope.schema.interfaces import IVocabularyFactory
 
+try:
+    from zope.app.component.hooks import getSite
+except ImportError:
+    from zope.component.hooks import getSite
+
 from zope.i18nmessageid import MessageFactory
 
 _ = MessageFactory('bda.plone.shop')
